@@ -418,6 +418,7 @@
 #define CURLOPT_HEADERDATA_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLOPT_HEADERFUNCTION_FIRST 0x070702 /* Added in 7.7.2 */
 #define CURLOPT_HEADEROPT_FIRST 0x072500 /* Added in 7.37.0 */
+#define CURLOPT_HTTP09_ALLOWED_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURLOPT_HTTP200ALIASES_FIRST 0x070a03 /* Added in 7.10.3 */
 #define CURLOPT_HTTPAUTH_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURLOPT_HTTPGET_FIRST 0x070801 /* Added in 7.8.1 */
@@ -429,6 +430,8 @@
 #define CURLOPT_HTTP_CONTENT_DECODING_FIRST 0x071002 /* Added in 7.16.2 */
 #define CURLOPT_HTTP_TRANSFER_DECODING_FIRST 0x071002 /* Added in 7.16.2 */
 #define CURLOPT_HTTP_VERSION_FIRST 0x070901 /* Added in 7.9.1 */
+#define CURLOPT_TRAILERFUNCTION_FIRST 0x074000 /* Added in 7.64.0 */
+#define CURLOPT_TRAILERDATA_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURLOPT_IGNORE_CONTENT_LENGTH_FIRST 0x070e01 /* Added in 7.14.1 */
 #define CURLOPT_INFILE_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_INFILESIZE_FIRST 0x070100 /* Added in 7.1 */
@@ -872,6 +875,8 @@
 #define CURL_PUSH_OK_FIRST 0x072c00 /* Added in 7.44.0 */
 #define CURL_READFUNC_ABORT_FIRST 0x070c01 /* Added in 7.12.1 */
 #define CURL_READFUNC_PAUSE_FIRST 0x071200 /* Added in 7.18.0 */
+#define CURL_TRAILERFUNC_OK_FIRST 0x074000 /* Added in 7.64.0 */
+#define CURL_TRAILERFUNC_ABORT_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURL_REDIR_GET_ALL_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURL_REDIR_POST_301_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURL_REDIR_POST_302_FIRST 0x071301 /* Added in 7.19.1 */
